==> members-facade-2.0.0-20191120.093028-165-sources.jar: com/bizvane/members/facade/service/inner/MembersAdvancedSearchService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.es.pojo.BasicMembersInfoSearchPojo;
import com.bizvane.members.facade.es.vo.GroupAbilityMembersInfoSearchVo;
import com.bizvane.members.facade.es.vo.GroupMixMembersInfoSearchVo;
import com.bizvane.members.facade.models.MemberInfoModel;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.springframework.data.domain.Page;

import com.bizvane.centerstageservice.models.po.FileTaskPo;
import com.bizvane.members.facade.es.pojo.MembersGroupAnalyzePojo;
import com.bizvane.members.facade.es.pojo.MembersInfoSearchPojo;
import com.bizvane.members.facade.es.pojo.qywx.MembersFriendPojo;
import com.bizvane.members.facade.es.vo.MembersGroupAnalyzeSearchVo;
import com.bizvane.members.facade.es.vo.MembersInfoSearchVo;
import com.bizvane.members.facade.vo.MemberInfoVo;
import com.bizvane.members.facade.vo.PageVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;

/**
 * Created by Administrator on 2018\8\13 0013.
 */
public interface MembersAdvancedSearchService {

    ResponseData<PageInfo<MemberInfoVo>> search(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersInfoSearchPojo>> advancedSearch(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<String> export(MembersInfoSearchVo membersInfoSearchVo, FileTaskPo fileTaskPo);

    ResponseData<Page<MembersFriendPojo>> searchMembersFriend(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersFriendPojo>> getMembersListOrder(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MemberInfoVo>> searchApi(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<BasicMembersInfoSearchPojo>> searchBasicMembers(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersInfoSearchPojo>> groupAbilitlyAdvancedSearch(GroupAbilityMembersInfoSearchVo groupAbilityMembersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MemberInfoModel>> groupMixAdvancedSearch(GroupMixMembersInfoSearchVo groupMixMembersInfoSearchVo, PageVo pageVo);
}

==> members-facade-2.0.1-20200722.064131-136-sources.jar: com/bizvane/members/facade/service/inner/MembersAdvancedSearchService.java <==
package com.bizvane.members.facade.service.inner;

import com.bizvane.members.facade.es.pojo.BasicMembersInfoSearchPojo;
import com.bizvane.members.facade.es.vo.GroupAbilityMembersInfoSearchVo;
import com.bizvane.members.facade.es.vo.GroupMixMembersInfoSearchVo;
import com.bizvane.members.facade.models.MemberInfoModel;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.springframework.data.domain.Page;

import com.bizvane.centerstageservice.models.po.FileTaskPo;
import com.bizvane.members.facade.es.pojo.MembersGroupAnalyzePojo;
import com.bizvane.members.facade.es.pojo.MembersInfoSearchPojo;
import com.bizvane.members.facade.es.pojo.qywx.MembersFriendPojo;
import com.bizvane.members.facade.es.vo.MembersGroupAnalyzeSearchVo;
import com.bizvane.members.facade.es.vo.MembersInfoSearchVo;
import com.bizvane.members.facade.vo.MemberInfoSimpleVO;
import com.bizvane.members.facade.vo.MemberInfoVo;
import com.bizvane.members.facade.vo.PageVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.web.bind.annotation.RequestBody;

import javax.validation.Valid;

/**
 * Created by Administrator on 2018\8\13 0013.
 */
public interface MembersAdvancedSearchService {

    ResponseData<PageInfo<MemberInfoVo>> search(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersInfoSearchPojo>> advancedSearch(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MemberInfoSimpleVO>> advancedSimpleSearch(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);
    
    ResponseData<String> export(MembersInfoSearchVo membersInfoSearchVo, FileTaskPo fileTaskPo);

    ResponseData<Page<MembersFriendPojo>> searchMembersFriend(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersFriendPojo>> getMembersListOrder(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MemberInfoVo>> searchApi(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<BasicMembersInfoSearchPojo>> searchBasicMembers(MembersInfoSearchVo membersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MembersInfoSearchPojo>> groupAbilitlyAdvancedSearch(GroupAbilityMembersInfoSearchVo groupAbilityMembersInfoSearchVo, PageVo pageVo);

    ResponseData<PageInfo<MemberInfoModel>> groupMixAdvancedSearch(GroupMixMembersInfoSearchVo groupMixMembersInfoSearchVo, PageVo pageVo);
}
